@@ -9,9 +9,7 @@ sub run {
 
   local $SIG{INT} = local $SIG{TERM} = sub { $self->{finished}++ };
 
-  my $worker = $self->app->minion->worker;
-  $worker->repair;
-  $worker->register;
+  my $worker = $self->app->minion->worker->repair->register;
   while (!$self->{finished}) {
     if   (my $job = $worker->dequeue) { $job->perform }
     else                              { sleep 5 }
@@ -26,7 +24,7 @@ sub run {
 
 =head1 NAME
 
-Minion::Command::minion::orker - Minion worker command
+Minion::Command::minion::worker - Minion worker command
 
 =head1 SYNOPSIS
 
